@@ -1,4 +1,4 @@
-/* $Id: msg_limits.h,v 1.22 2003/10/20 15:19:39 hadess Exp $ */
+/* $Id: msg_limits.h,v 1.23 2003/10/20 20:11:58 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -43,7 +43,7 @@ typedef struct _glibtop_msg_limits	glibtop_msg_limits;
 
 struct _glibtop_msg_limits
 {
-	u_int64_t	flags,
+	guint64	flags,
 		msgpool,	/* GLIBTOP_IPC_MSGPOOL	*/
 		msgmap,		/* GLIBTOP_IPC_MSGMAP	*/
 		msgmax,		/* GLIBTOP_IPC_MSGMAX	*/
