@@ -22,7 +22,6 @@
 #include <glib.h>
 #include <stdio.h>
 #include <sys/types.h>
-#include "mountlist.h"
 
 #if defined(STDC_HEADERS) || defined(HAVE_STRING_H)
 #include <string.h>
@@ -33,7 +32,18 @@
 #include <glibtop.h>
 #include <glibtop/mountlist.h>
 
-static struct mount_entry *read_filesystem_list (gboolean need_fs_type);
+/* A mount table entry. */
+struct mount_entry
+{
+  char *me_devname;             /* Device node pathname, including "/dev/". */
+  char *me_mountdir;            /* Mount point directory pathname. */
+  char *me_type;                /* "nfs", "4.2", etc. */
+  dev_t me_dev;                 /* Device number of me_mountdir. */
+  struct mount_entry *me_next;
+};
+
+
+static struct mount_entry *read_filesystem_list (void);
 
 #ifdef HAVE_SYS_PARAM_H
 #include <sys/param.h>
@@ -95,7 +105,7 @@ static struct mount_entry *read_filesystem_list (gboolean need_fs_type);
 #endif
 
 
-#if defined (MOUNTED_GETMNTINFO) && !defined (__NetBSD__) && !defined (__OpenBSD__)
+#if defined (MOUNTED_GETMNTINFO) && !defined (__NetBSD__) && !defined (__OpenBSD__) && !defined(__FreeBSD__)
 static const char *
 fstype_to_string (short t)
 {
@@ -207,12 +217,10 @@ fstype_to_string (int t)
 
 /* Return a list of the currently mounted filesystems, or NULL on error.
    Add each entry to the tail of the list so that they stay in order.
-   If NEED_FS_TYPE is nonzero, ensure that the filesystem type fields in
-   the returned list are valid.  Otherwise, they might not be.
 */
 
 static struct mount_entry *
-read_filesystem_list (gboolean need_fs_type)
+read_filesystem_list (void)
 {
   struct mount_entry *mount_list;
   struct mount_entry *me;
@@ -300,7 +308,7 @@ read_filesystem_list (gboolean need_fs_type)
 	me = (struct mount_entry *) g_malloc (sizeof (struct mount_entry));
 	me->me_devname = g_strdup (fsp->f_mntfromname);
 	me->me_mountdir = g_strdup (fsp->f_mntonname);
-#if defined(__NetBSD__) || defined(__OpenBSD__)
+#if defined(__NetBSD__) || defined(__OpenBSD__) || defined(__FreeBSD__)
 	me->me_type = g_strdup (fsp->f_fstypename);
 #else
 	me->me_type = g_strdup (fstype_to_string (fsp->f_type));
@@ -396,9 +404,8 @@ read_filesystem_list (gboolean need_fs_type)
 #endif
 	me->me_mountdir = g_strdup (mnt.mt_filsys);
 	me->me_dev = (dev_t) -1;	/* Magic; means not known yet. */
-	me->me_type = g_strdup ("");
+
 #ifdef GETFSTYP			/* SVR3.  */
-	if (need_fs_type)
 	  {
 	    struct statfs fsd;
 	    char typebuf[FSTYPSZ];
@@ -407,7 +414,10 @@ read_filesystem_list (gboolean need_fs_type)
 		&& sysfs (GETFSTYP, fsd.f_fstyp, typebuf) != -1)
 	      me->me_type = g_strdup (typebuf);
 	  }
+#else
+	me->me_type = g_strdup ("");
 #endif
+
 	me->me_next = NULL;
 
 	/* Add to the linked list. */
@@ -530,11 +540,14 @@ static gboolean ignore_mount_entry(const struct mount_entry *me)
 		"procfs",
 		"autofs",
 		"sysfs",
+		"usbfs",
 		"none",
 		"devpts",
 		"usbdevfs",
 		"binfmt_misc",
-		"supermount"
+		"supermount",
+		"mntfs",
+		"openpromfs"
 	};
 
 	const char (*i)[12] = &ignored[0];
@@ -563,7 +576,7 @@ glibtop_get_mountlist_s (glibtop *server, glibtop_mountlist *buf, int all_fs)
 
 	/* Read filesystem list. */
 
-	if((entries = read_filesystem_list (TRUE)) == NULL)
+	if((entries = read_filesystem_list ()) == NULL)
 		return NULL;
 
 	for (cur = &entries[0]; cur != NULL; cur = next) {
@@ -592,5 +605,9 @@ glibtop_get_mountlist_s (glibtop *server, glibtop_mountlist *buf, int all_fs)
 	buf->number = mount_array->len;
 	buf->total  = buf->number * buf->size;
 
+	buf->flags  = (1 << GLIBTOP_MOUNTLIST_SIZE)
+	  | (1 << GLIBTOP_MOUNTLIST_SIZE)
+	  | (1 << GLIBTOP_MOUNTLIST_TOTAL);
+
 	return (glibtop_mountentry*) g_array_free(mount_array, FALSE);
 }
