@@ -1,4 +1,4 @@
-/* $Id: loadavg.c,v 1.22 2004/07/03 13:28:59 bdejean Exp $ */
+/* $Id: loadavg.c,v 1.23 2004/09/23 22:44:53 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -62,7 +62,7 @@ glibtop_get_loadavg_s (glibtop *server, glibtop_loadavg *buf)
 
 	buf->flags = _glibtop_sysdeps_loadavg;
 
-	while (isspace(*p)) p++;
+	p = next_token(p);
 
 	/* Older Linux versions don't have the nr_running/nr_tasks fields. */
 
