@@ -1,4 +1,4 @@
-/* $Id: procsegment.c,v 1.21 2003/12/23 10:44:33 hadess Exp $ */
+/* $Id: procsegment.c,v 1.25 2004/09/23 08:13:28 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -37,34 +37,13 @@ static const unsigned long _glibtop_sysdeps_proc_segment_statm =
 (1L << GLIBTOP_PROC_SEGMENT_DATA_RSS) +
 (1L << GLIBTOP_PROC_SEGMENT_DIRTY_SIZE);
 
-#ifndef LOG1024
-#define LOG1024		10
-#endif
-
-/* these are for getting the memory statistics */
-static int pageshift;		/* log base 2 of the pagesize */
-
-/* define pagetok in terms of pageshift */
-#define pagetok(size) ((size) << pageshift)
-
 /* Init function. */
 
 void
 glibtop_init_proc_segment_s (glibtop *server)
 {
-	register int pagesize;
-
 	server->sysdeps.proc_segment = _glibtop_sysdeps_proc_segment |
 	  _glibtop_sysdeps_proc_segment_statm;
-
-	/* get the page size with "getpagesize" and calculate pageshift
-	 * from it */
-	pagesize = getpagesize ();
-	pageshift = 0;
-	while (pagesize > 1) {
-		pageshift++;
-		pagesize >>= 1;
-	}
 }
 
 /* Provides detailed information about a process. */
@@ -74,7 +53,8 @@ glibtop_get_proc_segment_s (glibtop *server, glibtop_proc_segment *buf,
 			    pid_t pid)
 {
 	char buffer [BUFSIZ], *p;
-	
+	const size_t pagesize = getpagesize();
+
 	glibtop_init_s (&server, GLIBTOP_SYSDEPS_PROC_SEGMENT, 0);
 
 	memset (buf, 0, sizeof (glibtop_proc_segment));
@@ -106,10 +86,10 @@ glibtop_get_proc_segment_s (glibtop *server, glibtop_proc_segment *buf,
 	buf->data_rss   = strtoull (p, &p, 0);
 	buf->dirty_size = strtoull (p, &p, 0);
 
-	buf->text_rss   <<= pageshift;
-	buf->shlib_rss  <<= pageshift;
-	buf->data_rss   <<= pageshift;
-	buf->dirty_size <<= pageshift;
+	buf->text_rss   *= pagesize;
+	buf->shlib_rss  *= pagesize;
+	buf->data_rss   *= pagesize;
+	buf->dirty_size *= pagesize;
 
 	buf->flags |= _glibtop_sysdeps_proc_segment_statm;
 }
