@@ -1,4 +1,4 @@
-/* $Id: mem.c,v 1.9 2003/10/20 15:19:59 hadess Exp $ */
+/* $Id: mem.c,v 1.11 2004/06/09 18:52:22 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -22,16 +22,16 @@
 */
 
 #include <glibtop/mem.h>
-#include <libgnome/gnome-i18n.h>
+#include "libgtop-i18n.h"
 
 const char *glibtop_names_mem [GLIBTOP_MAX_MEM] =
-{ 
+{
 	"total", "used", "free", "shared", "buffer",
 	"cached", "user", "locked"
 };
 
 const unsigned glibtop_types_mem [GLIBTOP_MAX_MEM] =
-{ 
+{
 	GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG,
 	GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG,
 	GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG
